HPLeftHandClient |release| Documentation
========================================

Overview
--------
**HPLeftHandClient** is a Python package containing a class that uses 
HTTP REST calls to talk with an HP LeftHand/StoreVirtual drive array.
distribution containing tools for working with
`LeftHand/StoreVirtual Storage Arrays <http://www.hp.com/go/storevirtual>`_. 
. This documentation attempts to explain
everything you need to know to use **HPLeftHandClient**.

:doc:`installation`
  Instructions on how to get the distribution.

:doc:`tutorial`
  Start here for a quick overview.

:doc:`api/index`
  The complete API documentation, organized by module.

Issues
------
.. todo:: create the open source website 
.. todo:: create the bug tracker

All issues should be reported (and can be tracked / voted for /
commented on) at the main `github issues
<https://github.com/WaltHP/python-hplefthandclient/issues>`_, in the "LeftHand Python Driver"
project.

Changes
-------
See the :doc:`changelog` for a full list of changes to HPLeftHandClient.


About This Documentation
------------------------
This documentation is generated using the `Sphinx
<http://sphinx.pocoo.org/>`_ documentation generator. The source files
for the documentation are located in the *doc/* directory of the
**HPLeftHandClient** distribution. To generate the docs locally run the
following command from the root directory of the **HPLeftHandClient** 

.. code-block:: bash

   $ python setup.py doc


.. toctree::
   :hidden:

   installation
   tutorial
   changelog
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

